Module config

Module config 

Structs

KagiConfig

Enums

RecordReplayMode
When the record/replay feature is enabled, determine if recording or replaying.

Constants

DEFAULT_API_BASE
ENV_PREFIX
The environment variable prefix giving way to the variables
REPLAY_LOG