pub enum KagiError {
ConfigError(ConfigError),
ReqwestError(Error),
StatusCodeError(StatusCode),
ReqwestMiddlewareError(Error),
VCRMiddlewareError(String),
UrlError(ParseError),
HeaderError(String),
EnvError(&'static str),
}Variants
ConfigError(ConfigError)
An error occurred while processing a crate::KagiConfig.
ReqwestError(Error)
An error occurred in connection with performing a reqwest.
StatusCodeError(StatusCode)
ReqwestMiddlewareError(Error)
An error performed while handling reqwest_middleware.
VCRMiddlewareError(String)
An error occurred while handling the particular rvcr recording middleware.
UrlError(ParseError)
An error occurred parsing a url::Url.
HeaderError(String)
An error occurred when formulating an HTTP header.
EnvError(&'static str)
An error occurred when reading an environment variable.