Module config
kagi_
api
0.1.1
Module config
Module Items
Structs
Enums
Constants
In crate kagi_
api
kagi_api
Module
config
Structs

Kagi
Config
Enums

Record
Replay
Mode
When the record/replay feature is enabled, determine if recording or replaying.
Constants

DEFAULT_
API_
BASE
ENV_
PREFIX
The environment variable prefix giving way to the variables
REPLAY_
LOG